@@ -467,7 +467,7 @@ class CommonQuerySet(QuerySet):
             res = [model_to_dict(record) for record in queryResult]
             return res
 
-    def get_range_rows3(self, start=None, end=None, function=None, json=None, distinct_field_names=None, *args):
+    def get_range_rows3(self, start=None, end=None, function=None, json=None, distinct_field_names=None, user=None, *args, **kwargs):
         queryResult = self._get_range_rows(*args, start=start, end=end, function=function, json=json, distinct_field_names=distinct_field_names)
 
         logger.debug(f'\n\n{queryResult.query}\n')
